import * as Helpers from "../helpers";
import jQuery from "jquery";

export { LinkSelectionOverlay };

/**
 * Represents an overlay showing the meaning of different edge colors.
 * Offers the ability to toggle certain edge types.
 */
class LinkSelectionOverlay {
    /**
     * Creates the link overlay for a given graph object.
     * @param {Graph} graph The graph object.
     */
    constructor(graph) {
        this.graph = graph;
    }

    /**
     * Creates the overlay based on the edges and nodes of the graph object.
     * Must be called after the graph has been initialized.
     */
    create() {
        const sceneNode = Helpers.getCanvasDivNode();
        const overlayNode = document.createElement("div");
        overlayNode.className = "link-overlay";
        sceneNode.insertBefore(overlayNode, sceneNode.childNodes[2]);

        const linkClasses = this.graph.getLinkClasses();
        const chars = Math.max.apply(
            Math,
            linkClasses.map(function (c) {
                return c.length;
            })
        );

        for (const link of linkClasses) {
            const relation = Helpers.createDiv("relation", overlayNode, {
                edgeType: link, // Attach the link type to the relation div object
                innerHTML: "<p>" + link + "</p>",
            });
            jQuery(relation).click((event) => this.toggleLinkVisibility(event));

            const colorStrip = Helpers.createDiv("rel-container", relation);
            colorStrip.style.backgroundColor = this.graph.edgeColors[link];
            colorStrip.style.width = 10 * chars + "px";
        }
    }

    /**
     * Event handler for the click event of the link type divs.
     * Toggles the visibility of certain edge types.
     * @param {MouseEvent} event
     */
    toggleLinkVisibility(event) {
        const target = event.currentTarget;
        this.graph.toggleLinkVisibility(target.edgeType);
        if (getComputedStyle(target).opacity == 1.0) {
            target.style.opacity = 0.4;
        } else {
            target.style.opacity = 1.0;
        }
    }
}
