import * as Graph from "../../graph";
import { CONTEXT } from "../../state";
import ToolMenu from "./toolmenu";

const HIDDEN_CLASS = "hidden";

export const SELECTION_KEY = "selection";

const CONTEXT_NOTHING = "#nothing-selected";
const CONTEXT_NODE = "#node-selected";
const CONTEXT_LINK = "#link-selected";

const NODE_NAME_ID = "#node-name";
const NODE_IMG_ID = "#node-image";
const NODE_DESC_ID = "#node-description";
const NODE_TYPE_ID = "#node-type";
const NODE_REF_ID = "#node-references";
const NODE_VIDEOS_ID = "#node-videos";
const NODE_MENU = [
    NODE_NAME_ID,
    NODE_IMG_ID,
    NODE_DESC_ID,
    NODE_TYPE_ID,
    NODE_REF_ID,
    NODE_VIDEOS_ID,
];

export class SelectMenu extends ToolMenu {
    constructor() {
        super();
        this.context = undefined;
        this.map = [
            { menu: NODE_NAME_ID, property: Graph.NODE_LABEL },
            { menu: NODE_IMG_ID, property: Graph.NODE_IMAGE },
            { menu: NODE_DESC_ID, property: Graph.NODE_DESCRIPTION },
            { menu: NODE_TYPE_ID, property: Graph.NODE_TYPE },
            { menu: NODE_REF_ID, property: Graph.NODE_REFERENCES },
            { menu: NODE_VIDEOS_ID, property: Graph.NODE_VIDEOS },
        ];
        this.hooked = false; // Can only hook menu events once, but have to do it later, when they are loaded
    }

    hookMenu() {
        NODE_MENU.forEach((menu) => {
            console.log(this.find(menu));
            // Subscribes to change event for each menu element
            this.find(menu).on("change", (e) => {
                var newValue = e.target.value;
                console.log(newValue);

                // Modify stored selection
                this.values[SELECTION_KEY][this.toProperty(menu)] = newValue;

                // Notify tool
                this.tool.onMenuChange(
                    SELECTION_KEY,
                    this.values[SELECTION_KEY]
                );
            });
        });
    }

    toProperty(menu) {
        for (var i = 0; i < this.map.length; i++) {
            if (this.map[i].menu === menu) {
                return this.map[i].property;
            }
        }
        return undefined;
    }

    toMenu(property) {
        for (var i = 0; i < this.map.length; i++) {
            if (this.map[i].property === property) {
                return this.map[i].menu;
            }
        }
        return undefined;
    }

    setContext(context) {
        if (context === this.context) {
            return; // Only do something if it changes
        }

        // Disable previous context
        this.getDomToContext(this.context).addClass(HIDDEN_CLASS);

        // Store and activate new context
        this.context = context;
        this.getDomToContext(this.context).removeClass(HIDDEN_CLASS);
    }

    getDomToContext(context) {
        var id = CONTEXT_NOTHING;

        if (context === CONTEXT.link) {
            id = CONTEXT_LINK;
        } else if (context === CONTEXT.node) {
            id = CONTEXT_NODE;
        }

        return this.find(id);
    }

    afterSet(key, value) {
        if (this.hooked !== true) {
            this.hookMenu();
            this.hooked = true;
        }

        if (key !== SELECTION_KEY) {
            return;
        }

        if (value.node) {
            this.fillNode(value);
            this.setContext(CONTEXT.node);
        } else if (value.link) {
            this.setContext(CONTEXT.link);
        } else {
            this.setContext(CONTEXT.nothing);
        }
    }

    fillNode(node) {
        NODE_MENU.forEach((menu) => {
            this.find(menu).val(node[this.toProperty(menu)]);
        });
    }
}
